@@ -4,10 +4,12 @@ from django.conf import settings
 
 from . import _create_django_model
 from . import _decorator
+from . import _inspect_dataclass
 from . import _store_setup
 from . import _sync_store
 from ._create_django_model import *
 from ._decorator import *
+from ._inspect_dataclass import *
 from ._store_setup import *
 from ._sync_store import *
 
@@ -17,7 +19,8 @@ __all__ = (
     + _sync_store.__all__
     + _store_setup.__all__
     + _create_django_model.__all__
+    + _inspect_dataclass.__all__
 )
 
 
-__version__ = "1.7.0"
+__version__ = "1.8.0"
