@@ -42,7 +42,7 @@ def register_app_label(app_label: str) -> None:
     BACKEND_LINKER.app_labels.add(app_label)
 
 
-def django_model(dataclass: type) -> type[models.Model]:
+def django_model(dataclass: type) -> "type[models.Model]":
     backend = BACKEND_LINKER.backend_class(dataclass)
     assert issubclass(backend, models.Model)
     return backend
