@@ -18,7 +18,7 @@ from ._protocols import T
 class DjangoStore:
     identifier: str
 
-    def dump(self, dc_obj: tp.Any) -> tuple[models.Model, bool]:
+    def dump(self, dc_obj: tp.Any) -> "tuple[models.Model, bool]":
         kwgs, m2m = self.dataclass_to_django(dc_obj)
         identifying, defaults = self._split_off_pk(dc_obj, kwgs)
         dj_obj, created = self.backend_manager(dc_obj).update_or_create(
